
#ifndef _C13_et635_
#define _C13_et635_

#ifdef __cplusplus
extern "C" {
#endif

extern void F1574_15529(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_BOOLEAN F1574_15530(EIF_REFERENCE);
extern EIF_REFERENCE F1574_15532(EIF_REFERENCE);
extern void EIF_Minit635(void);

#ifdef __cplusplus
}
#endif

#endif
